@@ -73,10 +73,6 @@ class _OMPLPlannerBase(ABC):
         self._planner.reset_is_valid(is_valid)
         self._is_valid = is_valid
 
-    @abstractmethod
-    def planner_type(self) -> Any:
-        ...
-
 
 class _UnconstrainedPlannerBase(_OMPLPlannerBase):
     def __init__(
@@ -95,104 +91,94 @@ class _UnconstrainedPlannerBase(_OMPLPlannerBase):
         assert lb.ndim == 1
         assert ub.ndim == 1
         assert len(lb) == len(ub)
-        planner_t = self.planner_type()
         if isinstance(validation_box, float):
             dim = len(lb)
             validation_box = np.array([validation_box] * dim)
-        self._planner = planner_t(
-            lb, ub, is_valid, n_max_is_valid, validation_box, algo.value, algo_range
+
+        self._planner = self._create_planner(
+            lb, ub, is_valid, n_max_is_valid, validation_box, algo, algo_range
         )
         self.reset_is_valid(is_valid)
         self._lb = lb
         self._ub = ub
 
+    @abstractmethod
+    def _create_planner(
+        self,
+        lb: VectorLike,
+        ub: VectorLike,
+        is_valid: IsValidFunc,
+        n_max_is_valid: int,
+        validation_box: np.ndarray,
+        algo: Algorithm = Algorithm.RRTConnect,
+        algo_range: Optional[float] = None,
+    ) -> Any:
+        ...
+
 
 class Planner(_UnconstrainedPlannerBase):
-    def planner_type(self) -> Any:
-        return _omplpy._OMPLPlanner
+    def _create_planner(
+        self,
+        lb: VectorLike,
+        ub: VectorLike,
+        is_valid: IsValidFunc,
+        n_max_is_valid: int,
+        validation_box: np.ndarray,
+        algo: Algorithm = Algorithm.RRTConnect,
+        algo_range: Optional[float] = None,
+    ) -> Any:
+        return _omplpy._OMPLPlanner(
+            lb, ub, is_valid, n_max_is_valid, validation_box, algo.value, algo_range
+        )
 
 
 class RepairPlanner(_UnconstrainedPlannerBase):
-    def planner_type(self) -> Any:
-        return _omplpy._LightningRepairPlanner
+    def _create_planner(
+        self,
+        lb: VectorLike,
+        ub: VectorLike,
+        is_valid: IsValidFunc,
+        n_max_is_valid: int,
+        validation_box: np.ndarray,
+        algo: Algorithm = Algorithm.RRTConnect,
+        algo_range: Optional[float] = None,
+    ) -> Any:
+        return _omplpy._LightningRepairPlanner(
+            lb, ub, is_valid, n_max_is_valid, validation_box, algo.value, algo_range
+        )
 
     def set_heuristic(self, traj_heuristic: np.ndarray) -> None:
         self._planner.set_heuristic(traj_heuristic)
 
 
-class ConstrainedPlanner(_OMPLPlannerBase):
-    def __init__(
+class ERTConnectPlanner(_UnconstrainedPlannerBase):
+    _is_set_heursitic: bool = False
+
+    def _create_planner(
         self,
-        eq_const: Callable[[np.ndarray], Tuple[np.ndarray, np.ndarray]],
         lb: VectorLike,
         ub: VectorLike,
         is_valid: IsValidFunc,
         n_max_is_valid: int,
-        validation_box: Union[np.ndarray, float],
+        validation_box: np.ndarray,
         algo: Algorithm = Algorithm.RRTConnect,
         algo_range: Optional[float] = None,
-    ):
-
-        lb = np.array(lb)
-        ub = np.array(ub)
-        assert lb.ndim == 1
-        assert ub.ndim == 1
-        assert len(lb) == len(ub)
-        planner_t = self.planner_type()
-        if isinstance(validation_box, float):
-            dim = len(lb)
-            validation_box = np.array([validation_box] * dim)
-
-        class ConstraintFunction:
-            jac_cache: Optional[np.ndarray] = None
-
-            def __call__(self, x: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
-                return eq_const(x)
-
-            def f(self, x: np.ndarray) -> List[float]:
-                val, jac = self.__call__(x)
-                self.jac_cache = jac
-                return val.tolist()
-
-            def jac(self, x: np.ndarray) -> List[List[float]]:
-                assert self.jac_cache is not None
-                return self.jac_cache.tolist()
-
-        const_fn = ConstraintFunction()
-        self._planner = planner_t(
-            const_fn.f,
-            const_fn.jac,
-            lb,
-            ub,
-            is_valid,
-            n_max_is_valid,
-            validation_box,
-            algo.value,
-            algo_range,
+    ) -> Any:
+        # NOTE: algo will not used in this planner
+        return _omplpy._ERTConnectPlanner(
+            lb, ub, is_valid, n_max_is_valid, validation_box
         )
-        self.reset_is_valid(is_valid)
-        self._lb = lb
-        self._ub = ub
 
     def solve(
         self, start: VectorLike, goal: VectorLike, simplify: bool = False
     ) -> Optional[List[np.ndarray]]:
+        if not self._is_set_heursitic:
+            raise RuntimeError("trajectory heuristic is not set")
+        return super().solve(start, goal, simplify)
 
-        # unlike unconstrained case, due to appliximation nature interpolation,
-        # start and goal can be deviated from true ones. Thus, we will apend them
-        np_start = np.array(start)
-        np_goal = np.array(goal)
-        traj = super().solve(start, goal, simplify=simplify)
-        if traj is None:
-            return None
-        if np.linalg.norm(traj[0] - np_start) > 1e-5:
-            traj[0] = np_start
-        if np.linalg.norm(traj[-1] - np_goal) > 1e-5:
-            traj[-1] = np_goal
-        return traj
-
-    def planner_type(self) -> Any:
-        return _omplpy._ConstrainedPlanner
+    def set_heuristic(self, traj_heuristic: np.ndarray) -> None:
+        self._planner.set_heuristic(traj_heuristic)
+        self._is_set_heursitic = True
 
 
 class LightningDB(_omplpy._LightningDB):
@@ -242,16 +228,84 @@ class LightningPlanner(_OMPLPlannerBase):
         assert lb.ndim == 1
         assert ub.ndim == 1
         assert len(lb) == len(ub)
-        planner_t = self.planner_type()
         if isinstance(validation_box, float):
             dim = len(lb)
             validation_box = np.array([validation_box] * dim)
-        self._planner = planner_t(
+        self._planner = _omplpy._LightningPlanner(
             db, lb, ub, is_valid, n_max_is_valid, validation_box, algo.value, algo_range
         )
         self.reset_is_valid(is_valid)
         self._lb = lb
         self._ub = ub
 
-    def planner_type(self) -> Any:
-        return _omplpy._LightningPlanner
+
+class ConstrainedPlanner(_OMPLPlannerBase):
+    def __init__(
+        self,
+        eq_const: Callable[[np.ndarray], Tuple[np.ndarray, np.ndarray]],
+        lb: VectorLike,
+        ub: VectorLike,
+        is_valid: IsValidFunc,
+        n_max_is_valid: int,
+        validation_box: Union[np.ndarray, float],
+        algo: Algorithm = Algorithm.RRTConnect,
+        algo_range: Optional[float] = None,
+    ):
+
+        lb = np.array(lb)
+        ub = np.array(ub)
+        assert lb.ndim == 1
+        assert ub.ndim == 1
+        assert len(lb) == len(ub)
+        if isinstance(validation_box, float):
+            dim = len(lb)
+            validation_box = np.array([validation_box] * dim)
+
+        class ConstraintFunction:
+            jac_cache: Optional[np.ndarray] = None
+
+            def __call__(self, x: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
+                return eq_const(x)
+
+            def f(self, x: np.ndarray) -> List[float]:
+                val, jac = self.__call__(x)
+                self.jac_cache = jac
+                return val.tolist()
+
+            def jac(self, x: np.ndarray) -> List[List[float]]:
+                assert self.jac_cache is not None
+                return self.jac_cache.tolist()
+
+        const_fn = ConstraintFunction()
+
+        self._planner = _omplpy._ConstrainedPlanner(
+            const_fn.f,
+            const_fn.jac,
+            lb,
+            ub,
+            is_valid,
+            n_max_is_valid,
+            validation_box,
+            algo.value,
+            algo_range,
+        )
+        self.reset_is_valid(is_valid)
+        self._lb = lb
+        self._ub = ub
+
+    def solve(
+        self, start: VectorLike, goal: VectorLike, simplify: bool = False
+    ) -> Optional[List[np.ndarray]]:
+
+        # unlike unconstrained case, due to appliximation nature interpolation,
+        # start and goal can be deviated from true ones. Thus, we will apend them
+        np_start = np.array(start)
+        np_goal = np.array(goal)
+        traj = super().solve(start, goal, simplify=simplify)
+        if traj is None:
+            return None
+        if np.linalg.norm(traj[0] - np_start) > 1e-5:
+            traj[0] = np_start
+        if np.linalg.norm(traj[-1] - np_goal) > 1e-5:
+            traj[-1] = np_goal
+        return traj
